<a href="https://github.com/AidenEllis/Cligo"><p align="center"></a>
<img height=100 src="https://upstorage.pythonanywhere.com/api/storage/file/its_sakib/Public/cligo/cligo.png"/>


<p align="center">
  <strong>CLI Go - Taking CLI Framework to the moon 🚀</strong>
</p>

<h3 align="center">
  <a href="https://github.com/AidenEllis/Cligo/blob/main/CONTRIBUTING.md">Contribute</a>
  <span> · </span>
  <a href="https://discord.gg/gbJ3sAeZkv">Community</a>
  <span> · </span>
  <a href="https://github.com/AidenEllis/Cligo/tree/main/docs">Documentation</a>
</h3>

---

## 🎫 Introduction :
Cligo (aka CLI Go) is a Python-based free and open-source CLI (Command line interface)
Framework. Cligo makes it easier & faster to build CLI
application.

The main goal of CliGo is to allow developers to focus on building commands,
instead of worrying about the process, execution & user input handeling.

And with our built-in components you can easily do stuffs like `checking 
permissions` (e.g., checking if the user is logged in), 
`user information`, `Handeling errors`, `Handeling inputs`, `Database` and more.

With our continuous updates you will keep getting new components and
features.


## Contributions

CliGo is open to contributions.

Please read [CONTRIBUTING.md](https://github.com/AidenEllis/Cligo/blob/main/CONTRIBUTING.md) for details on this project 
or visit our [Discord server](https://discord.gg/gbJ3sAeZkv)

## Code of Conduct

Please read [CODE_OF_CONDUCT.md](https://github.com/AidenEllis/Cligo/blob/main//CODE_OF_CONDUCT.md) for details on our code of conduct.
